#!/bin/bash

echo_stderr() {
        echo -e "$1" >&2
}


usage() {
        echo_stderr "Usage:\n\t$0 DOMAIN.NAME"
}

if [ -z "$1" ] ;then
        usage
        exit 1
else
apache_user=$(ps axu | egrep 'apache|httpd' | grep -v root| awk '{print $1}' | head -1)
  if [ -z "$apache_user" ] ; then
        echo "apache is not running, unable to get apache user"
        sleep 3
fi
export HTTPD_VHOSTS_D=`grep ^HTTPD_VHOSTS_D /etc/psa/psa.conf | awk '{print $2}'`

echo "SELECT d.name, h.www_root, s.login, s.home, h.webstat  FROM domains d, hosting h, sys_users s WHERE s.id=h.sys_user_id AND h.dom_id=d.id AND d.name='$1'" | mysql -Ns -uadmin -p`cat /etc/psa/.psa.shadow` -Dpsa | while read domain www user home webstat; do
echo domain = $domain www = $www user = $user dom_dir = $dom_dir $webstat;
dom_dir=$HTTPD_VHOSTS_D/$domain
#!dom_dir=$home

chown -f root:root $dom_dir
chmod -f 755 $dom_dir

chown -f $user:psaserv $www
chmod -f 750 $www
#--- httpdocs

chown -f $user:psaserv $www
chmod -f 750 $www

chown -fR $user:psacln $www/*

chown -fR $user:psacln $www/img
chmod -f 755 $www/img
chmod -f 755 $www/img/common
chmod -f 755 $www/img/icons
chmod -f 755 $www/img/apps
chmod -f 644$www/img/*
chmod -f 644 $www/img/common/*
chmod -f 644 $www/img/icons/*
chmod -f 644 $www/img/apps/*
#---------

chown -f root:root $dom_dir/dev/*
chmod -f 666 $dom_dir/dev/*

chown -f root:$apache_user $dom_dir/conf/*.include
chmod -f 640 $dom_dir/conf/*.include

chown -f root:psaserv $dom_dir/conf
chmod -f 750 $dom_dir/conf
chown -f root:root $dom_dir/conf/siteapp.d
chmod -f 755 $dom_dir/conf/siteapp.d

chown -f root:root $dom_dir/conf/siteapp.d/*.conf
chmod -f 600 $dom_dir/conf/siteapp.d/*.conf

chown -f $user:psaserv $dom_dir/cgi-bin
chmod -f 750 $dom_dir/cgi-bin
chown -f $user:psacln $dom_dir/cgi-bin/*
chmod -f 755 $dom_dir/cgi-bin/*

chown -f root:psaserv $dom_dir/subdomains
chmod -f 755 $dom_dir/subdomains

chown -f root:root $dom_dir/lib
chmod -f 755 $dom_dir/lib
chown -f root:root $dom_dir/lib/*
chmod -f 755 $dom_dir/lib/*

chown -f root:root $dom_dir/lib64
chmod -f 755 $dom_dir/lib64
chmod -f 755 $dom_dir/lib64/*
chown -f root:root $dom_dir/lib64/*

chown -f $user:root $dom_dir/private
chmod -f 0700 $dom_dir/private

chown -f root:psaserv $dom_dir/web_users
chmod -f 755 $dom_dir/web_users
chown -f $user:psaserv $dom_dir/web_users/*
chmod -f 750 $dom_dir/web_users/*

chown -f root:root $dom_dir/bin
chmod -f 755 $dom_dir/bin
chown -f root:root $dom_dir/bin/*
chmod -f 755 $dom_dir/bin/*

chown -f root:root $dom_dir/usr
chmod -f 755 $dom_dir/usr
chown -f root:root $dom_dir/usr/lib
chmod -f 755 $dom_dir/usr/lib
chown -f root:root $dom_dir/usr/libexec
chmod -f 755 $dom_dir/usr/libexec
chown -f root:root $dom_dir/usr/libexec/openssh
chmod -f 755 $dom_dir/usr/libexec/openssh
chown -f root:root $dom_dir/usr/libexec/openssh/sftp-server
chmod -f 755 $dom_dir/usr/libexec/openssh/sftp-server

chown -f root:psaserv $dom_dir/error_docs
chmod -f 755 $dom_dir/error_docs
chown -f $user:psacln $dom_dir/error_docs/*
chmod -f 644 $dom_dir/error_docs/*

chown -f root:root $dom_dir/etc
chmod -f 755 $dom_dir/etc
chown -f root:root $dom_dir/etc/passwd
chmod -f 644 $dom_dir/etc/passwd
chown -f root:root $dom_dir/etc/group
chmod -f 644 $dom_dir/etc/group
chown -f root:root $dom_dir/etc/termcap
chmod -f 755 $dom_dir/etc/termcap

chown -f root:psaserv $dom_dir/pd
chmod -f 750 $dom_dir/pd
chown -f $apache_user:$apache_user $dom_dir/pd/*
chmod -f 400 $dom_dir/pd/*

chown -f $user:psaserv $dom_dir/anon_ftp
chmod -f 750 $dom_dir/anon_ftp
chown -f root:psaserv $dom_dir/anon_ftp/conf
chmod -f 755 $dom_dir/anon_ftp/conf
chown -f $user:psaserv $dom_dir/anon_ftp/incoming
chmod -f 777 $dom_dir/anon_ftp/incoming
chown -f $user:psaserv $dom_dir/anon_ftp/pub
chmod -f 755 $dom_dir/anon_ftp/pub

chown -f root:root $dom_dir/tmp
chmod -f 1777 $dom_dir/tmp
chown -f root:root $dom_dir/var
chmod -f 755 $dom_dir/var
chown -f root:root $dom_dir/var/tmp
chmod -f 1777 $dom_dir/var/tmp

chown -f $user:psacln $www/css
chmod -f 755 $www/css
chown -f $user:psacln $www/css/*
chmod -f 644 $www/css/*

chown -f root:root $www/plesk-stat
chmod -f 755 $www/plesk-stat

chown -f root:psaserv $dom_dir/statistics
chmod -f 550 $dom_dir/statistics

chown -f root:root $dom_dir/statistics/ftpstat
chmod -f 755 $dom_dir/statistics/ftpstat

chown -f root:psaserv $dom_dir/statistics/ftpstat/index.html
chmod -f 644 $dom_dir/statistics/ftpstat/index.html

chown -f root:root $dom_dir/statistics/webstat
chmod -f 755 $dom_dir/statistics/webstat

chown -f root:psaserv $dom_dir/statistics/logs
chmod -f 550 $dom_dir/statistics/logs
chown -f root:root $dom_dir/statistics/logs/*
chmod -f 644 $dom_dir/statistics/logs/*


# ---------------- AWstats.begin ---------------
# the following code is for AWStats on domain

if [ $webstat = "awstats" ]; then

chown -f root:root $dom_dir/statistics/webstat/*
chmod -f 755 $dom_dir/statistics/webstat/*
chown -f root:psaserv $dom_dir/statistics/webstat/index.html
chmod -f 644 $dom_dir/statistics/webstat/index.html
chown -f root:root $dom_dir/statistics/webstat/nav.html
chmod -f 644 $dom_dir/statistics/webstat/nav.html
chown -f root:root $dom_dir/statistics/webstat/current
chmod -f 777 $dom_dir/statistics/webstat/current
chown -f root:root $dom_dir/statistics/webstat/*/awstats.*.html
chmod -f 644 $dom_dir/statistics/webstat/*/awstats.*.html
chown -f root:root $dom_dir/statistics/webstat/*/index.html
chmod -f 777 $dom_dir/statistics/webstat/*/index.html
chown -f root:root $dom_dir/statistics/webstat-ssl
chmod -f 755 $dom_dir/statistics/webstat-ssl
chown -f root:root $dom_dir/statistics/webstat-ssl/*
chmod -f 755 $dom_dir/statistics/webstat-ssl/*
chown -f root:psaserv $dom_dir/statistics/webstat-ssl/index.html
chmod -f 644 $dom_dir/statistics/webstat-ssl/index.html
chown -f root:root $dom_dir/statistics/webstat-ssl/nav.html
chmod -f 644 $dom_dir/statistics/webstat-ssl/nav.html
chown -f root:root $dom_dir/statistics/webstat-ssl/current
chmod -f 777 $dom_dir/statistics/webstat-ssl/current
chown -f root:root $dom_dir/statistics/webstat-ssl/*/awstats.*.html
chmod -f 644 $dom_dir/statistics/webstat-ssl/*/awstats.*.html
chown -f root:root $dom_dir/statistics/webstat-ssl/*/index.html
chmod -f 777 $dom_dir/statistics/webstat-ssl/*/index.html
chown -f root:root $dom_dir/statistics/anon_ftpstat
chmod -f 755 $dom_dir/statistics/anon_ftpstat
chown -f root:root $dom_dir/statistics/anon_ftpstat/*
chmod -f 755 $dom_dir/statistics/anon_ftpstat/*
chown -f root:psaserv $dom_dir/statistics/anon_ftpstat/index.html
chmod -f 644 $dom_dir/statistics/anon_ftpstat/index.html
chown -f root:root $dom_dir/statistics/anon_ftpstat/nav.html
chmod -f 644 $dom_dir/statistics/anon_ftpstat/nav.html
chown -f root:root $dom_dir/statistics/anon_ftpstat/current
chmod -f 777 $dom_dir/statistics/anon_ftpstat/current
chown -f root:root $dom_dir/statistics/anon_ftpstat/*/awstats.*.html
chmod -f 644 $dom_dir/statistics/anon_ftpstat/*/awstats.*.html
chown -f root:root $dom_dir/statistics/anon_ftpstat/*/index.html
chmod -f 777 $dom_dir/statistics/anon_ftpstat/*/index.html
chown -f root:root $dom_dir/statistics/ftpstat/current
chmod -f 777 $dom_dir/statistics/ftpstat/current
chown -f root:root $dom_dir/statistics/ftpstat/nav.html
chmod -f 644 $dom_dir/statistics/ftpstat/nav.html
chown -f root:root $dom_dir/statistics/ftpstat/*/awstats.*.html
chmod -f 644 $dom_dir/statistics/ftpstat/*/awstats.*.html
chown -f root:root $dom_dir/statistics/ftpstat/*
chmod -f 755 $dom_dir/statistics/ftpstat/*
chown -f root:root $dom_dir/statistics/ftpstat/*/index.html
chmod -f 777 $dom_dir/statistics/ftpstat/*/index.html
# ------- Awstats.end ----------------
fi

if [ $webstat = "webalizer" ]; then
# -------- Webalizer.begin -------------
# The following code is for Webalizer only
chown -f root:root $dom_dir/statistics/webstat/*
chmod -f 644 $dom_dir/statistics/webstat/*
chown -f root:root $dom_dir/statistics/webstat/index.html
chmod -f 755 $dom_dir/statistics/webstat/index.html
chown -f root:root $dom_dir/statistics/webstat-ssl/*
chmod -f 644 $dom_dir/statistics/webstat-ssl/*
chown -f root:root $dom_dir/statistics/webstat-ssl/index.html
chmod -f 755 $dom_dir/statistics/webstat-ssl/index.html
chown -f root:root $dom_dir/statistics/anon_ftpstat/index.html
chmod -f 755 $dom_dir/statistics/anon_ftpstat/index.html
# -------- Webalizer.end -------------
fi

done
fi
unset HTTPD_VHOSTS_D